---
title: 预设开关
---

# 预设开关

Global IM UIKit 提供了一些预设开关，用于控制部分功能的开启和关闭，开关定义可通过 `RCKitCommand` 枚举获取。

## 预设开关列表

| 预设开关                                                  | 默认值  | 说明                                                                                                                                     |
|:----------------------------------------------------------|:-------:|:---------------------------------------------------------------------------------------------------------------------------------------|
| `RCKitCommand.SHOW_CONNECTION_STATUS`                     | `true`  | 是否在开启的会话窗口中显示连接状态变更提醒                                                                                               |
| `RCKitCommand.SHOW_MESSAGE_STATE`                         | `true`  | 是否显示消息的已读状态；<br/>当功能关闭时，消息气泡中将仅展示消息的发送状态                                                                |
| `RCKitCommand.FOCUS_ON_LATEST_MESSAGE`                    | `true`  | 进入会话如何显示消息列表，**仅 Electron 平台支持修改**：<br/>`true`：滚动至消息列表最底部展示最新消息<br/>`false`：显示上次已读列表位置<br/> |
| `RCKitCommand.AT_ALL`                                     | `true`  | 是否支持群聊内 @ 全部成员功能                                                                                                            |
| `RCKitCommand.SHOW_USER_ONLINE_STATE`                     | `false` | 是否显示用户在线状态显示，需配合初始化时定义 `reqUserOnlineStatus` 钩子使用才能生效。                                                      |
| `RCKitCommand.PROMPT_SENDER_WHEN_QUOTE_MESSAGE`           | `true`  | 引用或回复消息时，默认 @ 消息发送者                                                                                                       |
| `RCKitCommand.DELETE_MESSAGES_WHILE_DELETE_CONVERSSATION` | `true`  | 删除会话的同时，是否删除本地与远端服务器存储的消息                                                                                        |

## 修改开关状态

开关状态修改仅限于 `kitApp.ready()` 之前调用生效，否则将不会生效。

以 `RCKitCommand.SHOW_CONNECTION_STATUS` 开关为例，修改开关状态的代码如下：

```js
import { RCKitCommand } from '@rongcloud/global-im-uikit';

kitApp.setCommand(RCKitCommand.SHOW_CONNECTION_STATUS, false);
```

## 获取开关状态

```js
import { RCKitCommand } from '@rongcloud/global-im-uikit';

const bool = kitApp.getCommandSwitch(RCKitCommand.SHOW_CONNECTION_STATUS);
```

